@@ -19,6 +19,7 @@
 #include <system_error>
 #include <random>
 #include <locale.h>
+#include <limits.h>
 #include "pplx/pplxtasks.h"
 #include "cpprest/details/basic_types.h"
 
@@ -28,7 +29,6 @@
 
 #ifndef _WIN32
 #include <sys/time.h>
-#include <boost/algorithm/string.hpp>
 #if !defined(ANDROID) && !defined(__ANDROID__) && defined(HAVE_XLOCALE_H) // CodePlex 269
 /* Systems using glibc: xlocale.h has been removed from glibc 2.26
    The above include of locale.h is sufficient
@@ -356,11 +356,45 @@ namespace details
     /// Our own implementation of alpha numeric instead of std::isalnum to avoid
     /// taking global lock for performance reasons.
     /// </summary>
-    inline bool __cdecl is_alnum(char ch)
+    inline bool __cdecl is_alnum(const unsigned char uch) noexcept
+    {   // test if uch is an alnum character
+        // special casing char to avoid branches
+        static constexpr bool is_alnum_table[UCHAR_MAX + 1] =
+            {
+            /*        X0 X1 X2 X3 X4 X5 X6 X7 X8 X9 XA XB XC XD XE XF */
+            /* 0X */   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+            /* 1X */   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+            /* 2X */   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+            /* 3X */   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, /* 0-9 */
+            /* 4X */   0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, /* A-Z */
+            /* 5X */   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0,
+            /* 6X */   0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, /* a-z */
+            /* 7X */   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0
+            /* non-ASCII values initialized to 0 */
+            };
+        return (is_alnum_table[uch]);
+    }
+
+    /// <summary>
+    /// Our own implementation of alpha numeric instead of std::isalnum to avoid
+    /// taking global lock for performance reasons.
+    /// </summary>
+    inline bool __cdecl is_alnum(const char ch) noexcept
     {
-        return (ch >= '0' && ch <= '9')
-            || (ch >= 'A' && ch <= 'Z')
-            || (ch >= 'a' && ch <= 'z');
+        return (is_alnum(static_cast<unsigned char>(ch)));
+    }
+
+    /// <summary>
+    /// Our own implementation of alpha numeric instead of std::isalnum to avoid
+    /// taking global lock for performance reasons.
+    /// </summary>
+    template<class Elem>
+    inline bool __cdecl is_alnum(Elem ch) noexcept
+    {
+        // assumes 'x' == L'x' for the ASCII range
+        typedef typename std::make_unsigned<Elem>::type UElem;
+        const auto uch = static_cast<UElem>(ch);
+        return (uch <= static_cast<UElem>('z') && is_alnum(static_cast<unsigned char>(uch)));
     }
 
     /// <summary>
@@ -393,19 +427,48 @@ namespace details
     }
 
     /// <summary>
-    /// Cross platform utility function for performing case insensitive string comparision.
+    /// Cross platform utility function for performing case insensitive string equality comparision.
     /// </summary>
     /// <param name="left">First string to compare.</param>
     /// <param name="right">Second strong to compare.</param>
     /// <returns>true if the strings are equivalent, false otherwise</returns>
-    inline bool str_icmp(const utility::string_t &left, const utility::string_t &right)
-    {
-#ifdef _WIN32
-        return _wcsicmp(left.c_str(), right.c_str()) == 0;
-#else
-        return boost::iequals(left, right);
-#endif
-    }
+    _ASYNCRTIMP bool __cdecl str_iequal(const std::string &left, const std::string &right) CPPREST_NOEXCEPT;
+
+    /// <summary>
+    /// Cross platform utility function for performing case insensitive string equality comparision.
+    /// </summary>
+    /// <param name="left">First string to compare.</param>
+    /// <param name="right">Second strong to compare.</param>
+    /// <returns>true if the strings are equivalent, false otherwise</returns>
+    _ASYNCRTIMP bool __cdecl str_iequal(const std::wstring &left, const std::wstring &right) CPPREST_NOEXCEPT;
+
+    /// <summary>
+    /// Cross platform utility function for performing case insensitive string less-than comparision.
+    /// </summary>
+    /// <param name="left">First string to compare.</param>
+    /// <param name="right">Second strong to compare.</param>
+    /// <returns>true if a lowercase view of left is lexicographically less than a lowercase view of right; otherwise, false.</returns>
+    _ASYNCRTIMP bool __cdecl str_iless(const std::string &left, const std::string &right) CPPREST_NOEXCEPT;
+
+    /// <summary>
+    /// Cross platform utility function for performing case insensitive string less-than comparision.
+    /// </summary>
+    /// <param name="left">First string to compare.</param>
+    /// <param name="right">Second strong to compare.</param>
+    /// <returns>true if a lowercase view of left is lexicographically less than a lowercase view of right; otherwise, false.</returns>
+    _ASYNCRTIMP bool __cdecl str_iless(const std::wstring &left, const std::wstring &right) CPPREST_NOEXCEPT;
+
+    /// <summary>
+    /// Convert a string to lowercase in place.
+    /// </summary>
+    /// <param name="target">The string to convert to lowercase.</param>
+    _ASYNCRTIMP void __cdecl inplace_tolower(std::string &target) CPPREST_NOEXCEPT;
+
+    /// <summary>
+    /// Convert a string to lowercase in place.
+    /// </summary>
+    /// <param name="target">The string to convert to lowercase.</param>
+    _ASYNCRTIMP void __cdecl inplace_tolower(std::wstring &target) CPPREST_NOEXCEPT;
 
 #ifdef _WIN32
 
@@ -607,41 +670,6 @@ private:
     interval_type m_interval;
 };
 
-#ifndef _WIN32
-
-// temporary workaround for the fact that
-// utf16char is not fully supported in GCC
-class cmp
-{
-public:
-
-    static int icmp(std::string left, std::string right)
-    {
-        size_t i;
-        for (i = 0; i < left.size(); ++i)
-        {
-            if (i == right.size()) return 1;
-
-            auto l = cmp::tolower(left[i]);
-            auto r = cmp::tolower(right[i]);
-            if (l > r) return 1;
-            if (l < r) return -1;
-        }
-        if (i < right.size()) return -1;
-        return 0;
-    }
-
-private:
-    static char tolower(char c)
-    {
-        if (c >= 'A' && c <= 'Z')
-            return static_cast<char>(c - 'A' + 'a');
-        return c;
-    }
-};
-
-#endif
-
 inline int operator- (datetime t1, datetime t2)
 {
     auto diff = (t1.m_interval - t2.m_interval);
