@@ -577,7 +577,8 @@ namespace Concurrency { namespace streams
         /// The data type of the basic element of the stream.
         /// </typeparam>
         /// <param name="buffer">A stream buffer.</param>
-        basic_istream(streams::streambuf<CharType> buffer) : m_helper(std::make_shared<details::basic_istream_helper<CharType>>(buffer))
+        template<class AlterCharType>
+        basic_istream(streams::streambuf<AlterCharType> buffer) : m_helper(std::make_shared<details::basic_istream_helper<CharType>>(std::move(buffer)))
         {
             _verify_and_throw(details::_in_streambuf_msg);
         }
@@ -801,7 +802,7 @@ namespace Concurrency { namespace streams
                     return true;
                 };
 
-            auto loop = Concurrency::details::_do_while([=]() mutable -> pplx::task<bool>
+            auto loop = pplx::details::_do_while([=]() mutable -> pplx::task<bool>
                 {
                     while (buffer.in_avail() > 0)
                     {
@@ -888,7 +889,7 @@ namespace Concurrency { namespace streams
                     return pplx::task_from_result(false);
                 };
 
-            auto loop = Concurrency::details::_do_while([=]() mutable -> pplx::task<bool>
+            auto loop = pplx::details::_do_while([=]() mutable -> pplx::task<bool>
                 {
                     while ( buffer.in_avail() > 0 )
                     {
@@ -968,7 +969,7 @@ namespace Concurrency { namespace streams
                 });
             };
 
-            auto loop = Concurrency::details::_do_while(copy_to_target);
+            auto loop = pplx::details::_do_while(copy_to_target);
 
             return loop.then([=](bool) mutable -> size_t
                 {
@@ -1142,7 +1143,7 @@ pplx::task<void> _type_parser_base<CharType>::_skip_whitespace(streams::streambu
             return false;
         };
 
-    auto loop = Concurrency::details::_do_while([=]() mutable -> pplx::task<bool>
+    auto loop = pplx::details::_do_while([=]() mutable -> pplx::task<bool>
         {
             while (buffer.in_avail() > 0)
             {
@@ -1217,7 +1218,7 @@ pplx::task<ReturnType> _type_parser_base<CharType>::_parse_input(
     return _skip_whitespace(buffer).then([=](pplx::task<void> op) -> pplx::task<ReturnType>
         {
             op.wait();
-            return Concurrency::details::_do_while(peek_char).then(finish);
+            return pplx::details::_do_while(peek_char).then(finish);
         });
 }
 
@@ -1747,7 +1748,7 @@ public:
 
     static pplx::task<std::wstring> parse(streams::streambuf<CharType> buffer)
     {
-        return _parse_input<std::basic_string<char>,std::basic_string<wchar_t>>(buffer, _accept_char, _extract_result);
+        return base::_parse_input<std::basic_string<char>,std::basic_string<wchar_t>>(buffer, _accept_char, _extract_result);
     }
 
 private:
